Utils - Blueye SDK

Skip to content


# Module blueye.sdk.utils

View Source

    import webbrowser

    import os

    import blueye.sdk

    def open_local_documentation():

        """Open a pre-built local version of the SDK documentation

        Useful when you are connected to the drone wifi, and don't have access to the online version.

        """

        sdk_path = os.path.dirname(blueye.sdk.__file__)

        # The documentation is located next to the top-level package so we move up a couple of levels

        documentation_path = os.path.abspath(

            sdk_path + "/../../blueye.sdk_docs/README.html"

        )

        webbrowser.open(documentation_path)

## Functions

### open_local_documentation

    def open_local_documentation(

    )

Open a pre-built local version of the SDK documentation

Useful when you are connected to the drone wifi, and don't have access to the online version.

View Source

    def open_local_documentation():

        """Open a pre-built local version of the SDK documentation

        Useful when you are connected to the drone wifi, and don't have access to the online version.

        """

        sdk_path = os.path.dirname(blueye.sdk.__file__)

        # The documentation is located next to the top-level package so we move up a couple of levels

        documentation_path = os.path.abspath(

            sdk_path + "/../../blueye.sdk_docs/README.html"

        )

        webbrowser.open(documentation_path)